import os
import re


def _get_version(version_filename: str) -> str:
    """Retrieves and checks version string from VERSION file

    Args:
        version_filename (str): File containing the version string

    Returns:
        str: Version string
    """
    with open(version_filename, "r") as fp:
        version_lines = fp.readlines()
        if len(version_lines) != 1:
            raise RuntimeError("VERSION file is malformed")
        version = version_lines[0]
        version_pattern = re.compile(r"^(\d+).(\d+).(\d+)(rc\d+|.dev\d+)?$")
        if not version_pattern.match(version):
            raise RuntimeError("VERSION string is malformed")
        return version


_VERSION_FILENAME = os.path.join(os.path.dirname(__file__), "VERSION")
__version__ = _get_version(_VERSION_FILENAME)
