"""app_configuration.py

Module for configuring all the application's global variables
"""

import os

MFLOG_LEVEL = "WARNING"
MFLOG_FILE = "promethee_mflog.json"
MFLOG_CONF = os.path.join(os.path.dirname(__file__), "promethee_mflog.conf")

MFLOG = {
    "json_file": MFLOG_FILE,
    "json_minimal_level": MFLOG_LEVEL,
    "override_files": MFLOG_CONF,
}


# Paths
RULES_XLS = {
    "default": os.path.join(os.path.dirname(__file__), "rules.xlsx"),
    "alpha": os.path.join(os.path.dirname(__file__), "rules.xlsx"),
    "psym": os.path.join(os.path.dirname(__file__), "rules_psym.xlsx"),
    "psym_archive": os.path.join(os.path.dirname(__file__), "rules_psym_archive.xlsx"),
}

ALL_GRID_NC = os.path.join(os.path.dirname(__file__), "all_grid.nc")

ALTITUDES_NC = os.path.join(os.path.dirname(__file__), "altitudes.nc")

TEMPLATES = {
    "period": os.path.join(
        os.path.dirname(__file__), "text", "period", "alertes_vh_time.ini"
    ),
    "multizone": {
        "generic": os.path.join(
            os.path.dirname(__file__), "text", "comment", "multizone.json"
        ),
        "snow": os.path.join(
            os.path.dirname(__file__), "text", "comment", "multizone_snow.json"
        ),
        "precip": os.path.join(
            os.path.dirname(__file__), "text", "comment", "multizone_precip.json"
        ),
    },
    "monozone": os.path.join(
        os.path.dirname(__file__), "text", "comment", "multizone.json"
    ),
}

# Working directory organization
WORKING_DIR = {
    "configs": {
        "global": "configs/global_config.tgz",
        "mask": "configs/mask_task_config.json",
        "data": "configs/data_task_config.json",
        "prod": "configs/prod_task_config.json",
        "version": "configs/version_config.json",
    },
    "data": "data/",
    "mask": "mask/",
    "output": "output/",
}

# Data conf
JSON_KWARGS = {"ensure_ascii": False}  # , "indent": 4}

ALTERNATE_MAX = 2

LOCAL = {
    "gridpoint": "[date:stdvortex]/[model]/[geometry:area]/[term:fmth].[format]",
    "promethee_gridpoint": (
        "[date:stdvortex]/[model]/[geometry:area]/"
        "[param].[begintime:fmth]_[endtime:fmth]_[step:fmth].[format]"
    ),
}

# Grib params
GRIB_PARAM_DTYPES = {
    "discipline": int,
    "parameterCategory": int,
    "productDefinitionTemplateNumber": int,
    "parameterNumber": int,
    "typeOfFirstFixedSurface": str,
    "level": int,
    "typeOfStatisticalProcessing": int,
    "derivedForecast": int,
    "percentileValue": int,
    "scaledValueOfLowerLimit": int,
    "lengthOfTimeRange": int,
    "units": str,
}

MANDATORY_GRIB_PARAM = ["name", "units", "startStep", "endStep", "stepRange"]

# Rules xls
RESOURCE_COLUMNS = [
    "kind",
    "model",
    "date",
    "geometry",
    "cutoff",
    "origin",
    "nativefmt",
]

# Path for saving localisation
AUTO_SAVE = False
LOCALISATION_REPO = "/scratch/labia/chabotv/temporarySaveLocalisation/"

# Texts formatting
DATETIME_FMT = "%Y%m%dT%H%M%S"
DATETIME_FMT_CDP = "%Y-%m-%dT%H:%M:%S"

LANGUAGE = "fr"
DATES_CONFIG = os.path.join(os.path.dirname(__file__), "text", "date.json")
SHORT_TERM_CONFIG = os.path.join(
    os.path.dirname(__file__), "text", "period", "short_term.csv"
)

TEXT_FORMAT = {
    "french": {
        "weekdays": [
            "lundi",
            "mardi",
            "mercredi",
            "jeudi",
            "vendredi",
            "samedi",
            "dimanche",
        ],
        "months": [
            "janvier",
            "février",
            "mars",
            "avril",
            "mai",
            "juin",
            "juillet",
            "août",
            "septembre",
            "octobre",
            "novembre",
            "décembre",
        ],
    },
    "english": {
        "weekdays": [
            "monday",
            "tuesday",
            "wednesday",
            "thursday",
            "friday",
            "saturday",
            "sunday",
        ],
        "months": [
            "january",
            "february",
            "march",
            "april",
            "may",
            "june",
            "july",
            "august",
            "september",
            "october",
            "november",
            "december",
        ],
    },
}

TAGS_FORMAT = {
    "time": {
        "fmth": "{:04d}",
        "fmthm": "{:04d}:00",
        "fmthhmm": "{:02d}:00",
        "fmtraw": "{:04d}00",
    },
    "datetime": {
        "julian": "%j",
        "ymd": "%Y%m%d",
        "yymd": "%y%m%d",
        "y": "%Y",
        "ymdh": "%Y%m%d%H",
        "yymdh": "%y%m%d%H",
        "ymdhm": "%Y%m%d%H%M",
        "ymdhms": "%Y%m%d%H%M%S",
        "mmddhh": "%m%d%H",
        "mm": "%m",
        "hm": "%H%M",
        "dd": "%d",
        "hh": "%H",
        "h": "%-H",
        "vortex": "%Y%m%dT%H%M%S",
        "stdvortex": "%Y%m%dT%H%M",
        "iso8601": "%Y-%m-%dT%H:%M:%SZ",
    },
}

TEXT_ALGO = {
    "wind": {
        "generic": {
            "fields": {
                "wind": "FF__HAUTEUR10",
                "gust": "RAF__HAUTEUR10",
                "direction": "DD__HAUTEUR10",
            }
        }
    },
    "temperature": {"generic": {"fields": {"temperature": "T__HAUTEUR2"}}},
    "weather": {
        "generic": {
            "fields": {
                "wwmf": "WWMF__SOL",
                "precip": "PRECIP__SOL",
                "rain": "EAU__SOL",
                "snow": "NEIPOT__SOL",
                "lpn": "LPN__SOL",
            }
        }
    },
    "wwmf": {
        "generic": {
            "fields": {
                "wwmf": "WWMF__SOL",
                "precip": "PRECIP__SOL",
                "rain": "EAU__SOL",
                "snow": "NEIPOT__SOL",
                "lpn": "LPN__SOL",
            }
        }
    },
    "thunder": {
        "generic": {"fields": {"orage": "RISQUE_ORAGE__SOL", "gust": "RAF__HAUTEUR10"}}
    },
    "visibility": {
        "generic": {"fields": {"visi": "VISI__SOL", "type_fg": "TYPE_FG__SOL"}}
    },
    "nebulosity": {"generic": {"fields": {"nebul": "NEBUL__SOL"}}},
    "precip": {
        "generic": {
            "fields": {
                "precip": "PRECIP__SOL",
                "rain": "EAU__SOL",
                "snow": "NEIPOT__SOL",
                "ptype": "PTYPE__SOL",
                "lpn": "LPN__SOL",
            }
        }
    },
    "snow": {"generic": {"fields": {"snow": "NEIPOT__SOL", "lpn": "LPN__SOL"}}},
}


# Liste des variables potentielles
PREFIX_TO_VAR = {
    "FF": "wind",
    "RAF": "gust",
    "NEIGE": "snow",
    "NEIPOT": "snow",
    "PRECIP": "precip",
    "EAU": "rain",
    "NEBUL": "nebul",
    "T": "temperature",
    "TMAX": "temperature",
    "TMIN": "temperature",
}
