"""
    Module d'interprétation de la conf
"""
import datetime as dt
from ftap_autom.promethee.src.conf.app_configuration import DATETIME_FMT
import mflog
from ftap_autom.promethee.src.conf.app_configuration import MFLOG

NO_VALUE = -9999

log = mflog.getLogger("conf_interpret.mod")
mflog.set_config(**MFLOG)
log = log.bind(module="interpretor")


class ConfInterpret:
    """
       Interpretation d'un configuration d'un parametre.
    """

    def __init__(self, config):
        """
        """
        self.config = config

    def get_reference_time(self):
        """get_reference_time
        Return the first hour for which promethee can produce a text.
        This is done through the interpretation of 'production_datetime' key.
        return:
            [datetime] : The datetime object
        """
        return dt.datetime.strptime(self.config["production_datetime"], DATETIME_FMT)

    def get_riskname(self):
        """
            Retourne le nom du risque.
        """
        return self.config.get("hazardName", self.config.get("name", ""))

    def get_threshold(self, risk_level, idx, var):
        """
            Fonction qui récupère le seuil d'une variable pour un niveau de
            risque et un évènement donnés.
            Retourne une String.
        """
        threshold = NO_VALUE
        for elt in self.config["levels"]:
            if elt["level"] == risk_level:
                threshold = elt["elementsEvent"][idx][var]["threshold"]
        return threshold

    def get_comparisonOp(self, risk_level, idx, var, elt1, elt2):
        """
            Fonction qui récupère l'opérateur de comparaison d'une variable pour
            un niveau de risque et un évènement donnés, et qui fait la traduction
            mathématique.
        """
        for elt in self.config["levels"]:
            if elt["level"] == risk_level:
                operateur = elt["elementsEvent"][idx][var]["comparisonOp"]
        if operateur in [">", "sup"]:
            condition = elt1 > elt2
        elif operateur in ["<", "inf"]:
            condition = elt1 < elt2
        elif operateur in [">=", "supegal"]:
            condition = elt1 >= elt2
        elif operateur in ["<=", "infegal"]:
            condition = elt1 <= elt2
        elif operateur in ["==", "egal"]:
            condition = elt1 == elt2
        elif operateur in ["!=", "dif"]:
            condition = elt1 != elt2
        else:
            log.error("operateur is not known", operateur=operateur)
        return condition

    def get_nb_evts(self, risk_levels):
        """
            Fonction qui renvoie le nombre d'évènements pour chaque niveau de risque
            donné en entrée
        """
        liste = []
        for elt in self.config["levels"]:
            for level in risk_levels:
                if elt["level"] == level:
                    nb_evt = elt["nbElementaryEvent"]
                    liste.append(nb_evt)
        return list(set(liste))

    def get_logicalOp(self, risk_level):
        """
            Fonction qui récupère l'opérateur logique pour un niveau de risque donné.
            Retourne une String.
        """
        for elt in self.config["levels"]:
            if elt["level"] == risk_level:
                logical_op = elt["logicalOpList"][0].lower()
        return logical_op
