import xarray as xr
import mflog
from ftap_autom.promethee.src.conf.app_configuration import MFLOG

LOGGER = mflog.getLogger("mask_processor")
mflog.set_config(**MFLOG)
LOGGER = LOGGER.bind(module="mask")

# Pour la création de masques netcdf
# options pour la génération.
xr.set_options(keep_attrs=True)


def generate_mask_by_altitude(domain, altitude, area_id):
    """ Genere des zones par tranche d'altitudes

    Args:
        domain (dataArray): Un dataArray contenant de 1 et des nans
        altitude (dataArray): Sur la même grille, contient des altitudes
        area_id (str): L'id du domaine à découper

    To Do : rajouter une option pour filtrer si les zones si les champs
        sont 'trop égaux'.
        Par exemple, si l'altitude max = 200, on crée <200 < 250  < 300  < 400
        qui sont identiques.

    Returns:
        dataArray:
          Contient les différentes découpes.
          Besoin d'avoir quelque chose de merger.
    """

    LOGGER.debug(
        "Entering generate mask by altitude",
        area_id=area_id,
        func="generate_mask_by_altitude",
    )
    Percent = 5
    MIN_ALT = [200, 250, 300, 400, 500]
    MAX_ALT = [
        250,
        300,
        350,
        400,
        500,
        600,
        700,
        800,
        900,
        1000,
        1200,
        1400,
        1600,
        1800,
        2000,
        2300,
        2600,
        2900,
        3200,
        3500,
    ]
    domain = domain.squeeze("id").reset_coords("id", drop=True)

    LOGGER.debug(
        f"max = {altitude.min().values} et min = {altitude.max().values}",
        area_id=area_id,
        func="generate_mask_by_altitude",
    )

    try:
        ds_alt = domain * altitude
    except Exception as e:
        print(domain)
        print(altitude)
        raise (e)
    alt_min = ds_alt.min().values
    alt_max = ds_alt.max().values
    if alt_min == alt_max and ds_alt.count() > 1:
        print(ds_alt.count())
        LOGGER.error(
            "Le fichier d'altitude ne semble pas correct. "
            f"Altitude min = {alt_min}; Altitude max = {alt_max}",
            alt_min=float(alt_min),
            alt_max=float(alt_max),
            area_id=area_id,
            func="generate_mask_by_altitude",
        )

    # Creation des inferieurs
    nb_pt = ds_alt.count()
    l_temp = []
    for alt in MIN_ALT:
        dtemp = (ds_alt < alt) * domain
        dtemp = dtemp.where(dtemp > 0)
        nb_current = dtemp.sum()

        if nb_current / nb_pt > Percent / 100:
            name = "en dessous de %s m" % alt
            dtemp = dtemp.expand_dims(dim="id").assign_coords(
                id=[area_id + "_inf_" + str(alt)]
            )
            dtemp["areaName"] = (("id"), [name])
            dtemp["areaType"] = (("id"), ["Altitude"])
            l_temp.append(dtemp)

    for alt in MAX_ALT:
        dtemp = (ds_alt > alt) * domain
        dtemp = dtemp.where(dtemp > 0)
        nb_current = dtemp.sum()
        if nb_current / nb_pt > Percent / 100:
            name = "au-dessus de %s m" % alt
            dtemp = dtemp.expand_dims(dim="id").assign_coords(
                id=[area_id + "_sup_" + str(alt)]
            )
            dtemp["areaName"] = (("id"), [name])
            dtemp["areaType"] = (("id"), ["Altitude"])
            l_temp.append(dtemp)

    dmerged = xr.merge(l_temp)  # .reset_coords(["areaName","areaType"])
    # Test sur le nombre des zones crées
    if dmerged.id.size > 5:
        return dmerged.reset_coords(["areaName", "areaType"])
    else:
        LOGGER.debug(
            f"Not enought area. Size is {dmerged.id.size}.",
            area_id=area_id,
            func="generate_mask_by_altitude",
        )
        return None
