"""
This little script enable us to change the geometry of a shapefile.
On top of changing the geometry, it enables to compute the area of
each polygon (in hectare).
To do so, we first project the inital geometry in EPSG:32643
(which has unit in meters) compute
the area and reproject in EPSG:4326 (which is a lat/lon regular geometry).

History
------------
Chabot V. 25/10/2019 : Creation

To do
------
1. Implement it as a function in order to be called when computing mask ?
2. Add input through and area computation through config file?
"""
from config import GEO_DIR, get_configuration
from osgeo import ogr, osr
import os
import sys

test = False
if len(sys.argv) < 2:
    input_shp = GEO_DIR + "Zone_France_Clim.json"
    output_shp = GEO_DIR + "Zone_France_Clim_4326.json"
    print("Default input file and output file are taken")
else:
    fname = sys.argv[1]
    config = get_configuration(fname, ["input_shp", "output_shp"])
    input_shp = config.pop("input_shp")
    output_shp = config.pop("output_shp")
    test = config.get("test", False)

print("Input file is %s\n Output file is %s." % (input_shp, output_shp))

driver = ogr.GetDriverByName("GeoJSON")
data_source = driver.Open(input_shp)
layer = data_source.GetLayer()

sourceprj = layer.GetSpatialRef()
targetprj = osr.SpatialReference()
targetprj.ImportFromEPSG(4326)

# Transformation

transform = osr.CoordinateTransformation(sourceprj, targetprj)
# Specifying output
to_fill = ogr.GetDriverByName("GeoJSON")
if os.path.exists(output_shp):
    os.remove(output_shp)
ds = to_fill.CreateDataSource(output_shp)
outLayer = ds.CreateLayer("", targetprj, ogr.wkbPolygon)
number_of_field_added = 0
inLayerDefn = layer.GetLayerDefn()
for i in range(0, inLayerDefn.GetFieldCount()):
    fieldDefn = inLayerDefn.GetFieldDefn(i)
    outLayer.CreateField(fieldDefn)

# get the output layer's feature definition
outLayerDefn = outLayer.GetLayerDefn()

# apply transformation
i = 0
if test:
    feature = layer[0]
    transformed = feature.GetGeometryRef()
    transformed.Transform(transform)

else:
    for feature in layer:
        transformed = feature.GetGeometryRef()
        transformed.Transform(transform)
        geom = ogr.CreateGeometryFromWkb(transformed.ExportToWkb())
        defn = outLayer.GetLayerDefn()
        feat = ogr.Feature(defn)
        # print(area)
        for k in range(number_of_field_added, outLayerDefn.GetFieldCount()):
            current_name = feature.GetField(k - number_of_field_added)
            if current_name is None:
                current_name = ""
            if isinstance(current_name, str):
                # Solving problem of non ascii
                if not current_name.isascii():
                    import unicodedata

                    current_name = (
                        unicodedata.normalize("NFKD", current_name)
                        .encode("ISO-8859-1", "ignore")
                        .decode("ISO-8859-1")
                    )
            feat.SetField(outLayerDefn.GetFieldDefn(k).GetNameRef(), current_name)
        feat.SetGeometry(geom)
        outLayer.CreateFeature(feat)
        i += 1
        feat = None
ds = None
