"""
This little script enable us to change the geometry of a shapefile.
On top of changing the geometry, it enables to compute the area of
each polygon (in hectare).
To do so, we first project the inital geometry in EPSG:32643
(which has unit in meters) compute
the area and reproject in EPSG:4326 (which is a lat/lon regular geometry).

History
------------
Chabot V. 25/10/2019 : Creation

To do
------
1. Implement it as a function in order to be called when computing mask ?
2. Add input through and area computation through config file?
"""
from config import GEO_DIR, get_configuration
from osgeo import ogr, osr
import os
import sys

test = True
get_area = False

if len(sys.argv) < 2:
    input_shp = GEO_DIR + "Bassin_Hydro/BASSIN_VERSANT_TOPOGRAPHIQUE.shp"
    output_shp = GEO_DIR + "Bassin_Hydro/BASSIN_VERSANT_TOPOGRAPHIQUE_4326.shp"
    print("Default input file and output file are taken")
else:
    fname = sys.argv[1]
    config = get_configuration(fname, ["input_shp", "output_shp"])
    input_shp = config.pop("input_shp")
    output_shp = config.pop("output_shp")
    test = config.get("test", False)

print("Input file is %s\n Output file is %s." % (input_shp, output_shp))

driver = ogr.GetDriverByName("ESRI Shapefile")
data_source = driver.Open(input_shp)
layer = data_source.GetLayer()

x = layer[0]
type_geom = x.GetGeometryRef().GetGeometryName()

sourceprj = layer.GetSpatialRef()
targetprj = osr.SpatialReference()
targetprj.ImportFromEPSG(4326)
targetprj_area = osr.SpatialReference()
targetprj_area.ImportFromEPSG(32643)  # To get area of surface


# Transformation
if get_area:
    transform_forarea = osr.CoordinateTransformation(sourceprj, targetprj_area)
    transform = osr.CoordinateTransformation(targetprj_area, targetprj)
else:
    transform = osr.CoordinateTransformation(sourceprj, targetprj)

# Specifying output
to_fill = ogr.GetDriverByName("Esri Shapefile")
if os.path.exists(output_shp):
    os.remove(output_shp)
ds = to_fill.CreateDataSource(output_shp)

if type_geom == "LINESTRING":
    outLayer = ds.CreateLayer("", targetprj, ogr.wkbLineString)
else:
    outLayer = ds.CreateLayer("", targetprj, ogr.wkbPolygon)

outLayer.CreateField(ogr.FieldDefn("new_id", ogr.OFTInteger))
if get_area:
    new_field = ogr.FieldDefn("area-ha", ogr.OFTReal)
    new_field.SetWidth(32)
    new_field.SetPrecision(2)
    outLayer.CreateField(new_field)
    number_of_field_added = 2
else:
    number_of_field_added = 1
inLayerDefn = layer.GetLayerDefn()
for i in range(0, inLayerDefn.GetFieldCount()):
    fieldDefn = inLayerDefn.GetFieldDefn(i)
    outLayer.CreateField(fieldDefn)

# get the output layer's feature definition
outLayerDefn = outLayer.GetLayerDefn()

# apply transformation
i = 0
if test:
    feature = layer[0]
    transformed = feature.GetGeometryRef()
    if get_area:
        transformed.Transform(transform_forarea)
        area = transformed.GetArea() / 1000000  # Get Area in ha
        print("Aire (en ha) %s" % area)
    transformed.Transform(transform)
    print("Aire (en deg^2)%s" % transformed.GetArea())
else:
    for feature in layer:
        transformed = feature.GetGeometryRef()
        if get_area:
            transformed.Transform(transform_forarea)
            area = transformed.GetArea() / 10000
        transformed.Transform(transform)
        geom = ogr.CreateGeometryFromWkb(transformed.ExportToWkb())
        defn = outLayer.GetLayerDefn()
        feat = ogr.Feature(defn)
        feat.SetField("new_id", i)
        if get_area:
            feat.SetField("area-ha", area)
        # print(area)
        for k in range(number_of_field_added, outLayerDefn.GetFieldCount()):
            current_name = feature.GetField(k - number_of_field_added)
            if current_name is None:
                current_name = ""
            # print(type(current_name))
            if isinstance(current_name, str):
                # Solving problem of non ascii
                if not current_name.isascii():
                    import unicodedata

                    current_name = (
                        unicodedata.normalize("NFKD", current_name)
                        .encode("ISO-8859-1", "ignore")
                        .decode("ISO-8859-1")
                    )
                    # print("And is now %s"%current_name)
            feat.SetField(outLayerDefn.GetFieldDefn(k).GetNameRef(), current_name)
        feat.SetGeometry(geom)
        outLayer.CreateFeature(feat)
        i += 1
        feat = None
ds = None
