from config import GEO_DIR, GRID_DIR, get_configuration
import create_grid_mask as cgm
import os
import sys

# Transitoire pour tester plusieurs cas
fname = sys.argv[1]
config = get_configuration(fname, ["input_sig_file", "output_directory"])
print("Configuration is %s" % config)

GEO_DIR = config.pop("GEO_DIR", GEO_DIR)
input_file = os.path.join(GEO_DIR, config.pop("input_sig_file"))
OUTPUT_BASE = config.pop("OUTPUT_BASE", GEO_DIR)
output_directory = os.path.join(OUTPUT_BASE, config.pop("output_directory"))
input_grid = config.get("input_grid", os.path.join(GRID_DIR, "EURW1S100.nc"))
config.setdefault("input_grid_format", "netcdf")

# On check si les valeurs d'entree sont coherente
if not os.path.exists(input_grid):
    raise (ValueError("Input grid does not exist %s" % input_grid))
if not os.path.exists(input_file):
    raise (
        ValueError("Input mask file (geojson, shp, ?) does not exist %s" % input_file)
    )

os.makedirs(output_directory, exist_ok=True)

mask_handler = cgm.generate_grid_mask(
    input_file, input_grid, output_directory, **config
)

input_format = config.get("input_format", "geojson")
if "id_key" not in config:
    print("Warning we impose ID to be id_key as it is not in configuration")
id_key = config.pop("id_key", "ID")

if input_format == "geojson":
    mask_handler.loop_for_geojson(id_key=id_key, **config)
#                              lev_id=2,
#                              lev1_id="properties",
#                              prop_keys=config.get("prop_keys",["name","NOM_DEPT"]),

elif input_format == "shp":
    mask_handler.loop_for_shapefile(id_key=id_key, **config)
else:
    raise ("Input format not known. Get %s" % input_format)
