"""
@package text.comment.monozone

Module retrieving text templates
"""

# Standard packages
from __future__ import annotations

# Third parties packages
import mflog

# Own package
from ftap_autom.promethee.src.conf.app_configuration import MFLOG, TEMPLATES
from ftap_autom.promethee.src.lib.text.comment.component import ComponentInterface
from ftap_autom.promethee.src.lib.text.comment.comment_builder import (
    TemplateCommentBuilder,
    PeriodCommentBuilder,
)
from ftap_autom.promethee.src.lib.text.template import read_file

# Logging
mflog.set_config(**MFLOG)
LOGGER = mflog.getLogger("text.comment.monozone.mod")
LOGGER = LOGGER.bind(module="text.comment.monozone")


def new_monozone() -> MonoZone:
    """new_monozone: temporary function that creates a full MonoZone
    CommentBuilder out of the box.

    Returns:
        MonoZone: new monozone comment builder object.
    """
    return MonoZone(read_file(TEMPLATES["monozone"]))


class MonoZone(TemplateCommentBuilder, PeriodCommentBuilder):
    """MonoZone: specific CommentBuilder for handling 'monozone' types of
    components.

    Args:
        template_retriever (TemplateRetriever): Object that is able to find and
            provide a template corresponding to the self.component_handler.

    Inheritance:
        TemplateCommentBuilder
        PeriodCommentBuilder
    """

    def process(self, component_handler: ComponentInterface) -> str:
        """process: method for processing a full self.comment according to the
        given component_handler.

        Args:
            component_handler (ComponentInterface): Object handling all the component's
                features necessary to create an appropriate comment.
        """
        self.reset()
        self.component_handler = component_handler
        self.retrieve_template()
        self.process_period()
        return self.comment
