"""
@package lib.text.generator

Synthesis text generator
"""

# Standard packages
from datetime import datetime

# Third parties packages
import mflog

# Own package
from ftap_autom.promethee.src.conf.app_configuration import DATETIME_FMT, MFLOG
from ftap_autom.promethee.src.lib.text.pheno.factory import PhenoFactory
from ftap_autom.promethee.src.utils.my_profile import logwrap

# Logging
mflog.set_config(**MFLOG)
LOGGER = mflog.getLogger("text.generator.mod")
LOGGER = LOGGER.bind(module="text_generator")


class TextGenerator:
    def __init__(self, id, name, production_datetime, period, geos, weather, **kwargs):
        self.id = id
        self.name = name
        self.production_datetime = datetime.strptime(production_datetime, DATETIME_FMT)
        self.geos = geos
        self.period = {
            "id": period.get("id", ""),
            "name": period.get("name", ""),
            "start": datetime.strptime(period["start"], DATETIME_FMT),
            "stop": datetime.strptime(period["stop"], DATETIME_FMT),
        }
        self.weather = weather
        self.kwargs = kwargs
        self.time_dimension = kwargs.pop("time_dimension", "step")
        if self.time_dimension == "step":
            LOGGER.info(
                "Time dimension has been set to default. "
                "Please check if this is correct.",
                time_dimension=self.time_dimension,
                text_id=self.id,
                period_id=self.period.get("id"),
                func="__init__",
            )

    def generate_weather(self, weather_idx):
        pheno_factory = PhenoFactory(self.geos, **self.weather[weather_idx])
        if pheno_factory.satisfy_condition():
            return pheno_factory.generate()
        return ""

    @logwrap(logger=LOGGER)
    def generate(self):
        my_text = ""
        for weather_idx in range(len(self.weather)):
            my_text += self.generate_weather(weather_idx) + "\n"

        return {"comments": {self.id: my_text}}
