"""
@package lib.text.pheno.factory

Phenonmenon factory for synthesis text generation
"""
# Standard packages

# Third parties packages
import mflog

# Own package
from ftap_autom.promethee.src.conf.app_configuration import MFLOG
from ftap_autom.promethee.src.lib.interpretor import EventInterp
from ftap_autom.promethee.src.lib.risk_generator import UnitaryEvent
from ftap_autom.promethee.src.lib.text.pheno.pheno import Pheno
from ftap_autom.promethee.src.lib.text.pheno.temperature import TemperatureGeneric
from ftap_autom.promethee.src.lib.text.pheno.wind import WindGeneric
from ftap_autom.promethee.src.lib.text.pheno.snow import SnowGeneric
from ftap_autom.promethee.src.lib.text.pheno.wwmf import WWMFGeneric


# Logging
mflog.set_config(**MFLOG)
LOGGER = mflog.getLogger("text.pheno.factory.mod")
LOGGER = LOGGER.bind(module="text_pheno_factory")


class PhenoFactory:
    def __init__(self, geos, id, condition, fields, algo="generic"):
        self.id = id
        self.algo = algo
        self.condition = condition
        self.geos = geos
        self.fields = fields
        self.pheno = self.get_pheno()

    def get_pheno(self):
        pheno = Pheno
        if self.id == "temperature":
            pheno = TemperatureGeneric
        elif self.id == "wind":
            pheno = WindGeneric
        elif self.id == "snow":
            pheno = SnowGeneric
        elif self.id == "wwmf":
            pheno = WWMFGeneric
        else:
            pheno = Pheno
        return pheno(self.geos, **self.fields)

    def satisfy_condition(self):
        if not self.condition:
            # Cas où il n'y a pas de condition à remplir
            return True

        fields = self.condition.pop("field", [])
        if not fields:
            return True

        flist = []
        for field in fields:
            try:
                cval = (
                    UnitaryEvent(
                        EventInterp(
                            dict(
                                field=field,
                                geos=self.geos,
                                compute_list=[],
                                **self.condition
                            )
                        )
                    )
                    .compute_event()
                    .values.any()
                )
            except BaseException:
                LOGGER.error(
                    "Unitary event failed.",
                    field=field["file"],
                    func="statisfy_condition",
                    pheno_id=self.id,
                    exc_info=True,
                )
                cval = True

            flist += [cval]

        return any(flist)

    def generate(self):
        return self.pheno.generate()
