"""
@package lib.text.pheno.temperature

Temperature text module
"""

# Standard packages

# Third parties packages
import mflog
import xarray as xr

# Own package
from ftap_autom.promethee.src.conf.app_configuration import MFLOG
from ftap_autom.promethee.src.lib.aggregator import Aggregator
from ftap_autom.promethee.src.utils.unit_converter import convert_dataarray
from ftap_autom.promethee.src.lib.interpretor import EventInterp
from ftap_autom.promethee.src.lib.risk_generator import UnitaryEvent
from ftap_autom.promethee.src.lib.text.pheno.pheno import Pheno
from ftap_autom.promethee.src.utils.my_profile import logwrap

# Logging
mflog.set_config(**MFLOG)
LOGGER = mflog.getLogger("text.temperature.mod")
LOGGER = LOGGER.bind(module="text.temperature")


class TemperatureGeneric(Pheno):
    def __init__(self, geos, temperature, *args, **kwargs):
        super().__init__(geos, *args, **kwargs)
        self.temperature = temperature
        self.units = kwargs.get("units", {"temperature": "°C"})
        self._values = None

    @property
    def values(self):
        if isinstance(self._values, xr.Dataset):
            return self._values
        values_list = []
        for field in self.temperature:
            event = UnitaryEvent(EventInterp({"field": field, "geos": self.geos}))
            agg_handler = Aggregator(event.field, mask=event.mask)
            mini_da = convert_dataarray(
                agg_handler.compute("min"), self.units["temperature"]
            )
            maxi_da = convert_dataarray(
                agg_handler.compute("max"), self.units["temperature"]
            )
            values_list += [xr.Dataset({"mini": mini_da, "maxi": maxi_da})]
        self._values = xr.merge(values_list)
        return self._values

    @logwrap(logger=LOGGER)
    def generate(self):
        try:
            mini = int(self.values["mini"].values.round().min())
            maxi = int(self.values["maxi"].values.round().max())
            text = f"Température : mini={mini}°C, maxi={maxi}°C"
        except BaseException:
            text = "Température : données non disponibles"
        return text
