""" main.py

Main "binary" file
Execute the whole Promethee pipeline :
    - Processing configuration
    - Preprocessing raw model data files
    - Creating missing masks
    - Generating Promethee components

! Module currently deprecated !
"""
import os
import sys
import json
from datetime import datetime


from ftap_autom.promethee.src.conf.app_configuration import (
    RULES_XLS,
    ALL_GRID_NC,
    JSON_KWARGS,
)
from ftap_autom.promethee.src.lib.config_processor import ConfigProcessor
from ftap_autom.promethee.src.lib.data_preprocessor import DataPreprocessor
from ftap_autom.promethee.src.lib.mask_processor import MaskProcessor
from ftap_autom.promethee.src.lib.parameter_generator import ParameterGeneratorTransit

PROD_DATETIME = datetime(2020, 6, 10, 23, 35, 46)
NPROC = 4
BATCH_SIZE = 128

if __name__ == "__main__":
    # -------------------------------------------------------------------------
    #    Working directory retrieving and setting paths
    # -------------------------------------------------------------------------
    working_dir = "./"
    if len(sys.argv) > 1:
        working_dir = sys.argv[1]

    global_config = os.path.join(working_dir, "configs/global_config.json")
    mask_config = os.path.join(working_dir, "configs/mask_config.json")
    prod_config = os.path.join(working_dir, "configs/prod_config.json")
    data_config = os.path.join(working_dir, "configs/data_config.json")

    # -------------------------------------------------------------------------
    #    Config processing
    # -------------------------------------------------------------------------
    config_processor = ConfigProcessor(
        global_config_filename=global_config,
        rules_xls=RULES_XLS,
        production_datetime=PROD_DATETIME,
        working_dir=working_dir,
    )
    mask_dico, data_dico, prod_dico = config_processor.process_all(nproc=NPROC)

    # Mask config
    with open(mask_config, "w") as mask_f:
        json.dump(mask_dico, mask_f, **JSON_KWARGS)

    # Prod config
    with open(prod_config, "w") as prod_f:
        json.dump(prod_dico, prod_f, **JSON_KWARGS)

    # Data config
    with open(data_config, "w") as data_f:
        json.dump(data_dico, data_f, **JSON_KWARGS)

    # -------------------------------------------------------------------------
    #    Data Preprocessing
    # -------------------------------------------------------------------------
    if not os.path.isdir(os.path.join(working_dir, "data/promethee/")):
        data_handler = DataPreprocessor(data_config)
        data_handler.preprocess(nproc=NPROC, batch_size=BATCH_SIZE)

    # -------------------------------------------------------------------------
    #    Mask Preprocessing
    # -------------------------------------------------------------------------
    if not os.path.isdir(os.path.join(working_dir, "mask/")):
        for conf in mask_dico:
            mask_handler = MaskProcessor(conf, ALL_GRID_NC)
            mask_handler.create_masks()

    # -------------------------------------------------------------------------
    #    Risk Production
    # -------------------------------------------------------------------------
    for bulletin in prod_dico:
        for component in bulletin["components"]:
            if component["type"] != "Risk":
                continue
            print(component["uid"])
            param_handler = ParameterGeneratorTransit(**component)
            param_handler.compute_risks()
            da_occu = param_handler.get_final_risk_level().dropna("step", how="all")
            output_path = os.path.join(
                working_dir, "data/output/{}.nc".format(component["uid"][0])
            )
            os.makedirs(os.path.dirname(output_path), exist_ok=True)
            da_occu.to_netcdf(output_path)
