""" preprocess_data.py

Preprocessing data 'binary' file
Preprocesses raw model data files (grib files) according to a given "data" configuration
"""
import argparse

from ftap_autom.promethee.src.conf.app_configuration import WORKING_DIR, RULES_XLS
from ftap_autom.promethee.src.lib.data_preprocessor import DataPreprocessor

if __name__ == "__main__":
    # Arguments parsing
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-f",
        "--filename",
        default=WORKING_DIR["configs"]["data"],
        type=str,
        help=(
            "Relative path (from the working directory)"
            " to the data configuration file to process."
        ),
    )
    parser.add_argument(
        "-n",
        "--nproc",
        default=16,
        type=int,
        help="Number of CPU to use for multiprocessing.",
    )
    parser.add_argument(
        "-b",
        "--batchsize",
        default=128,
        type=int,
        help="Maximum number of files being processed simultaneously."
        "This number should approximately be the available RAM in GB.",
    )
    parser.add_argument(
        "-r",
        "--rules",
        default=list(RULES_XLS.keys())[0],
        type=str,
        help="Name of the rules convention (for files selection)."
        "This argument must be a key of the app_configuration.RULES_XLS dictionary.",
    )
    args = parser.parse_args()
    print(args)

    # Preprocessing
    preprocessor = DataPreprocessor(args.filename, args.rules)
    preprocessor.preprocess(nproc=args.nproc, batch_size=args.batchsize)
